@@ -1,20 +1,11 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2011 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "core/operationstack.h"
 #include "core/device.h"
@@ -452,9 +443,9 @@ void OperationStack::push(Operation* o)
         o->setStatus(Operation::StatusPending);
     }
 
-    // emit operationsChanged even if o is nullptr because it has been merged: merging might
+    // Q_EMIT operationsChanged even if o is nullptr because it has been merged: merging might
     // have led to an existing operation changing.
-    emit operationsChanged();
+    Q_EMIT operationsChanged();
 }
 
 /** Removes the topmost Operation from the OperationStack, calls Operation::undo() on it and deletes it. */
@@ -463,7 +454,7 @@ void OperationStack::pop()
     Operation* o = operations().takeLast();
     o->undo();
     delete o;
-    emit operationsChanged();
+    Q_EMIT operationsChanged();
 }
 
 /** Check whether previous operations involve given partition.
@@ -499,7 +490,7 @@ void OperationStack::clearOperations()
         delete o;
     }
 
-    emit operationsChanged();
+    Q_EMIT operationsChanged();
 }
 
 /** Clears the list of Devices. */
@@ -509,7 +500,7 @@ void OperationStack::clearDevices()
 
     qDeleteAll(previewDevices());
     previewDevices().clear();
-    emit devicesChanged();
+    Q_EMIT devicesChanged();
 }
 
 /** Finds a Device a Partition is on.
@@ -549,7 +540,7 @@ void OperationStack::addDevice(Device* d)
     QWriteLocker lockDevices(&lock());
 
     previewDevices().append(d);
-    emit devicesChanged();
+    Q_EMIT devicesChanged();
 }
 
 static bool deviceLessThan(const Device* d1, const Device* d2)
@@ -567,5 +558,5 @@ void OperationStack::sortDevices()
 
     std::sort(previewDevices().begin(), previewDevices().end(), deviceLessThan);
 
-    emit devicesChanged();
+    Q_EMIT devicesChanged();
 }
